@@ -19,9 +19,9 @@ from botocore.client import ClientMeta
 
 from .literals import ChangeTypeType, FormatTypeType, locationTypeType
 from .type_defs import (
-    CreateChangesetResponseTypeDef,
-    GetProgrammaticAccessCredentialsResponseTypeDef,
-    GetWorkingLocationResponseTypeDef,
+    CreateChangesetResponseResponseTypeDef,
+    GetProgrammaticAccessCredentialsResponseResponseTypeDef,
+    GetWorkingLocationResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -52,7 +52,7 @@ class Exceptions:
 
 class FinSpaceDataClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/finspace-data.html#FinSpaceData.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/finspace-data.html#FinSpaceData.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html)
     """
 
@@ -61,7 +61,9 @@ class FinSpaceDataClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#can_paginate)
         """
 
@@ -75,9 +77,11 @@ class FinSpaceDataClient:
         formatType: FormatTypeType = None,
         formatParams: Dict[str, str] = None,
         tags: Dict[str, str] = None
-    ) -> CreateChangesetResponseTypeDef:
+    ) -> CreateChangesetResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
+        Creates a new changeset in a FinSpace dataset.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_changeset)
         """
 
@@ -89,22 +93,29 @@ class FinSpaceDataClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#generate_presigned_url)
         """
 
     def get_programmatic_access_credentials(
         self, *, environmentId: str, durationInMinutes: int = None
-    ) -> GetProgrammaticAccessCredentialsResponseTypeDef:
+    ) -> GetProgrammaticAccessCredentialsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
+        Request programmatic credentials to use with Habanero SDK.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_programmatic_access_credentials)
         """
 
     def get_working_location(
         self, *, locationType: locationTypeType = None
-    ) -> GetWorkingLocationResponseTypeDef:
+    ) -> GetWorkingLocationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
+        A temporary Amazon S3 location to copy your files from a source location to
+        stage or use as a scratch space in Habanero notebook.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_working_location)
         """
